@@ -8,11 +8,11 @@ IPC::Run3 - run a subprocess with input/ouput redirection
 
 =head1 VERSION
 
-version 0.043_02
+version 0.043_03
 
 =cut
 
-our $VERSION = '0.043_02';
+our $VERSION = '0.043_03';
 
 =head1 SYNOPSIS
 
@@ -22,9 +22,10 @@ our $VERSION = '0.043_02';
 
 =head1 DESCRIPTION
 
-This module allows you to run a subprocess and redirect stdin, stdout,
-and/or stderr to files and perl data structures.  It aims to satisfy 99% of the
-need for using C<system>, C<qx>, and C<open3> 
+C<run3> uses the C<system> function to run a subprocess or shell
+command, with stdin, stdout, and/or stderr conveniently redirected
+to or from files, Perl data structures, or subroutines.
+It aims to satisfy 99% of the need for using C<system>, C<qx>, and C<open3> 
 with a simple, extremely Perlish API.
 
 Speed, simplicity, and portability are paramount.  (That's speed of Perl code;
@@ -369,20 +370,30 @@ sub run3 {
     open STDERR_SAVE, ">&STDERR" or croak "run3(): $! saving STDERR"
         if defined $err_fh;
 
+    # If dup'ing below FROM a filehandle that represents a STD... filehandle
+    # (i.e. fileno $fh <= 2), we may have dup'ed TO that filehandle 
+    # earlier (depending on the order of open statements below).
+    # An example is
+    #
+    #   run3 [ ... ], \undef, \*STDERR, \*STDOUT;
+    #
+    # But we already have filehandles that should be "safe" to
+    # dup from. So if fileno $fh <= 2 we don't dup from $fh,
+    # but from the corresponding *_SAVE filehandle instead.
+    my @saves = (fileno STDIN_SAVE, fileno STDOUT_SAVE, fileno STDERR_SAVE);
+
     my $errno;
     my $ok = eval {
-        open STDIN,  "<&=" . fileno $in_fh
+
+        open STDIN,  "<&" . _dup_from($in_fh, \@saves)
             or croak "run3(): $! redirecting STDIN"
             if defined $in_fh;
 
-#        close $in_fh or croak "$! closing STDIN temp file"
-#            if ref $stdin;
-
-        open STDOUT, ">&" . fileno $out_fh
+        open STDOUT, ">&" . _dup_from($out_fh, \@saves)
             or croak "run3(): $! redirecting STDOUT"
             if defined $out_fh;
 
-        open STDERR, ">&" . fileno $err_fh
+        open STDERR, ">&" . _dup_from($err_fh, \@saves)
             or croak "run3(): $! redirecting STDERR"
             if defined $err_fh;
 
@@ -448,6 +459,13 @@ sub run3 {
     return 1;
 }
 
+sub _dup_from {
+    my ($fh, $filenos) = @_;
+
+    my $dup_from = fileno $fh;
+    return defined $filenos->[$dup_from] ? $filenos->[$dup_from] : $dup_from;
+}
+
 1;
 
 __END__
@@ -473,6 +491,10 @@ had a successful exit code. Hence you should always check C<$?>.
 See L</%options> for an option to handle the case of C<system>
 returning -1 yourself.
 
+Note that C<run3> is subject to the same restrictions as C<system>,
+e.g. C<SIGINT> and C<SIGQUIT> are ignored during the execution of C<$cmd>
+(cf. L<perlfunc/system>).
+
 =head3 C<$cmd>
 
 Usually C<$cmd> will be an ARRAY reference and the child is invoked via
